function addtrack

% ADDTRACK: add a track in the current window
%
%	See also: MKMENUS.

%	A.Wrench Dec 1999

%global h_axes h_lines h_crsr h_val
%global tlim tmin tmax
%global h_specgram
global tlim %tmin tmax
%find every axis belonging to THE CURRENT figure with an Ematools tag  
h_axes = findobj(gcf,'Type','axes');
h_axes = sort(h_axes);
%find any lines belonging to these axes with a waveform tag (ie. not a cursor tag)
h_lines = findobj(h_axes,'Tag','WaveForm');
h_labelaxis =  findobj(gcf,'Type','axes', 'Tag', 'LAB');
if ishandle(h_labelaxis)
  h_mrkr = findobj(h_labelaxis,'Tag','MarkerLine');
  h_label = findobj(h_labelaxis,'Tag','MarkerText');
end
%find ant cursors belonging to these axes
h_crsr1 = findobj(h_axes,'Tag','Cursor','Userdata',1);
h_crsr2 = findobj(h_axes,'Tag','Cursor','Userdata',2);
%find all tmax tmin and period values for these axes
list = get(h_axes,'Userdata');
if ~iscell(list)
   tmax = list(1);
   tmin = list(2);
   period = list(3);
else
for i=1:length(list) 
   tmax(i)=list{i,1}(1,1);
   tmin(i)=list{i,1}(1,2);
   period(i)=list{i,1}(1,3);
end
end
color1 = 'red';
color2 = [0, 0.5, 0];

h_fig = gcf; 

if isempty(h_fig)
  return;
end

figure(h_fig);

ntracks = length(h_axes);

period = .005;
t = 0:period:tlim(2);

top = 0.9;
base = 0.1;
height = (top - base)/(ntracks+1);


for i = 1:ntracks
   set(h_axes(i),'Position',[0.1,top - i*height,0.85, height*0.8],...
      'XTickLabel', '');
   set(get(h_axes(i),'xlabel'),'String','');
	ylim = get(h_axes(i),'YLim');
   set(h_crsr1(i),'YData',ylim);
   set(h_crsr2(i),'YData',ylim);
end

%period(i) = 0.001;
callbackstring = [...
   'activate;'];

for i = ntracks+1
   h_newaxis = axes('Units','normalized','Position',[0.1,top - i*height,0.85, height*0.8],...
     'DrawMode','fast','NextPlot','add','Box','on',...
     'Tag','FREE',...
     'UserData',[tmax(ntracks) tmin(ntracks) period],... 
	  'XTickLabelMode', 'manual',...
     'YTickLabelMode', 'manual',...
     'ButtonDownFcn',callbackstring,...
     'XLim',tlim,'FontName','Courier','FontSize',10);

  set(get(h_newaxis,'xlabel'),'FontName','Courier','FontSize',10,'Userdata',period);

  set(get(h_newaxis,'ylabel'),'FontName','Courier','FontSize',10);
  
h_newline = line(t,zeros(size(t)),'Tag','WaveForm',...
   'Selected', 'On',...
   'color', 'Black',...
   'SelectionHighlight', 'Off',...
   'ButtonDownFcn',callbackstring);

%set x axis tick mark labels at the bottom of the screen only
  set(h_newaxis,'XTickLabelMode', 'auto');
  set(get(h_newaxis,'xlabel'),'FontName','Courier','FontSize',10,...
                      'String','Time (s)');

ylim = get(h_newaxis,'YLim');
%If there are markers then copy them
if ishandle(h_labelaxis)

  h_newmrkr = copyobj(h_mrkr,h_newaxis);
  set(h_newmrkr,'Ydata',ylim);
end
%h_newlabel = copyobj(h_label,h_newaxis);
%set(h_newlabel,'FontName','Helvetica','FontSize',8,...
%   'Visible','Off','UserData',h_newmrkr);
%string = get(h_label,'String')
callbackstring = [...
   'activate;'...
   'cursor start;'];

	posit = get(h_crsr1(ntracks),'Xdata');
	h_newcrsr1 = line('Erasemode','xor','Color',color1,'LineStyle','-',...
              'Xdata',posit,'Ydata',ylim,'Visible','on',...
              'ButtonDownFcn',callbackstring,...
           'Userdata',1,'Tag','Cursor');
	posit = get(h_crsr2(ntracks),'Xdata');
	h_newcrsr2 = line('Erasemode','xor','Color',color2,'LineStyle','-',...
              'Xdata',posit,'Ydata',ylim,'Visible','on',...
              'ButtonDownFcn',callbackstring,...
           'Userdata',2,'Tag','Cursor');

  h_newval1 = text(0,0,num2str(posit));
  set(h_newval1,'EraseMode','Xor','Color',color1,'FontName','Courier',...
             'FontSize',10,'Units','Normalize','Position',[0 1.15 0],...
             'UserData',1,'Tag','CursorText');

  h_newval2 = text(0,0,num2str(posit));
  set(h_newval2,'EraseMode','Xor','Color',color2,'FontName','Courier',...
             'FontSize',10,'Units','Normalize','Position',[.6 1.15 0],...
             'UserData',2,'Tag','CursorText');
  newactivate(h_newaxis);

end

