function catchpts(opt)

% CATCHPTS: draw a 2-sigma ellipse around the set of points
%       comprised within a predelimited area in the selected figure
%
%       See also: EL2SIG

%       N. Nguyen, Sept. 96


side = ['vrt1';'vrt2';'hrz1';'hrz2'];

if ~exist('opt')

  h_fig = findobj('Type','figure');

  set(h_fig,'Pointer','fleur');

  fprintf(1,'\nSelect the figure on which the ellipse is to be drawn.\n');

  waitforbuttonpress;

  set(h_fig,'Pointer','arrow');

  zoom off

  fprintf(1,'\nDelimit the set of points with the mouse.\n');

  set(gcf,'WindowButtonDownFcn','catchpts(''draw'');');

elseif strcmp(opt,'draw')

  set(gcf,'WindowButtonDownFcn','');

  pt = get(gca,'CurrentPoint');

  for i = 1:4

    line([pt(1,1) pt(1,1)],[pt(1,2) pt(1,2)],'EraseMode','Xor',...
      'LineStyle','--','UserData',side(i,:));

  end

  callbackstring = [...
    'pt = get(gca,''CurrentPoint'');'...
    'h_line1 = findobj(gca,''UserData'',''vrt1'');'...
    'h_line2 = findobj(gca,''UserData'',''vrt2'');'...
    'h_line3 = findobj(gca,''UserData'',''hrz1'');'...
    'h_line4 = findobj(gca,''UserData'',''hrz2'');'...
    'y = get(h_line1,''YData'');'...
    'set(h_line1,''YData'',[y(1) pt(1,2)]);'...
    'y = get(h_line2,''YData'');'...
    'set(h_line2,''XData'',[pt(1,1) pt(1,1)],''YData'',[y(1) pt(1,2)]);'...
    'x = get(h_line3,''XData'');'...
    'set(h_line3,''XData'',[x(1) pt(1,1)]);'...
    'x = get(h_line4,''XData'');'...
    'set(h_line4,''XData'',[x(1) pt(1,1)],''YData'',[pt(1,2) pt(1,2)]);'];

  set(gcf,'WindowButtonMotionFcn',callbackstring);
  
  set(gcf,'WindowButtonUpFcn','catchpts(''catch'');');

elseif strcmp(opt,'catch')

  set(gcf,'WindowButtonUpFcn','');
  set(gcf,'WindowButtonMotionFcn','');

  x1 = get(findobj('UserData','vrt1'),'XData');
  x2 = get(findobj('UserData','vrt2'),'XData');
  y1 = get(findobj('UserData','hrz1'),'YData');
  y2 = get(findobj('UserData','hrz2'),'YData');

  xmin = min([x1(1) x2(1)]); xmax = max([x1(1) x2(1)]);
  ymin = min([y1(1) y2(1)]); ymax = max([y1(1) y2(1)]);

  for i = 1:4
    delete(findobj('UserData',side(i,:)));
  end

  h_lines = findobj(gca,'Type','line');

  for i = 1:length(h_lines)

    M = [M ; get(h_lines(i),'XData')' get(h_lines(i),'YData')'];

  end

  idx = find(M(:,1) >= xmin(1) & M(:,1) <= xmax(1) & ...
             M(:,2) >= ymin(1) & M(:,2) <= ymax(1));

  x = M(idx,1);
  y = M(idx,2);

  if length(x) == 0
    return;
  end

  h_lines = el2sig(x,y);

  resp = input('(a)ccept / (c)ancel: ','s');

  if strcmp(resp,'a')
    return;
  elseif strcmp(resp,'c')
    delete(h_lines);
  end

end

