function config

% CONFIG: configuration panel allowing to reset the
%        values of different global variables

%        N. Nguyen, July 96.

global FILEDIR NTRACKS aud_sr ema_sr epg_sr plot_coils tongue_coils ema_pal_name
global ref1 ref2

h_fig = findobj('Name','Configuration Panel');

if ~isempty(h_fig)
  return;
end

figure;

set(gcf,'Name','Configuration Panel','NumberTitle','off',...
        'UserData','EMA Tools');

axis off;

% ---------------------------------------------------------
% general parameters

uicontrol(gcf,'Style','frame','Units','Normal','Position',[.005 .83 .5 .14]);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .9 .2 .05],...
              'String','data directory:','HorizontalAlignment','left');

callbackstring = [...
  'global FILEDIR;'...
  'FILEDIR = get(get(gcf,''CurrentObject''),''String'');'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.25 .9 .245 .05],...
              'String',FILEDIR,'HorizontalAlignment','left','Max',1,...
              'Callback',callbackstring);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .85 .25 .05],...
              'String','nb. of tracks:','HorizontalAlignment','left');

callbackstring = [...
  'global NTRACKS;'...
  'n = str2num(get(get(gcf,''CurrentObject''),''String''));'...
  'if (n ~= NTRACKS); NTRACKS = n; mktracks(NTRACKS); end;'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.25 .85 .245 .05],...
              'String',NTRACKS,'HorizontalAlignment','left','Max',1,...
              'Callback',callbackstring);

% ---------------------------------------------------------
% sampling rates

uicontrol(gcf,'Style','frame','Units','Normal','Position',[.005 .63 .5 .19]);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .75 .25 .05],...
              'String','audio sampling rate:','HorizontalAlignment','left');

callbackstring = [...
  'global aud_sr;'...
  'aud_sr = str2num(get(get(gcf,''CurrentObject''),''String''));'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.25 .75 .245 .05],...
              'String',aud_sr,'HorizontalAlignment','left','Max',1,...
              'Callback',callbackstring);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .7 .25 .05],...
              'String','EMA sampling rate:','HorizontalAlignment','left');

callbackstring = [...
  'global ema_sr;'...
  'ema_sr = str2num(get(get(gcf,''CurrentObject''),''String''));'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.25 .7 .245 .05],...
              'String',ema_sr,'HorizontalAlignment','left','Max',1,...
              'Callback',callbackstring);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .65 .25 .05],...
              'String','EPG sampling rate:','HorizontalAlignment','left');

callbackstring = [...
  'global epg_sr;'...
  'epg_sr = str2num(get(get(gcf,''CurrentObject''),''String''));'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.25 .65 .245 .05],...
              'String',epg_sr,'HorizontalAlignment','left','Max',1,...
              'Callback',callbackstring);

% ---------------------------------------------------------
% palate outlines

uicontrol(gcf,'Style','frame','Units','Normal','Position',[.005 .33 .5 .29]);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .55 .3 .05],...
              'String','EMA palate:','HorizontalAlignment','left');

callbackstring = [...
  'global ema_pal;'...
  'ema_pal = eval(get(get(gcf,''CurrentObject''),''String''));'...
  'h_win = findobj(''Name'',''EMA Prof.'');'...
  'if ~isempty(h_win); fprintf(1,''ok''); h_pal = findobj(h_win,''UserData'',''PAL'');'...
  'set(h_pal,''XData'',ema_pal(:,1),''YData'',ema_pal(:,2)); end;'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.2 .55 .3 .05],...
              'String',sprintf('%s ',ema_pal_name),'HorizontalAlignment','left','Max',1,...
              'Callback',callbackstring);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .45 .15 .05],...
              'String','Ref 1:','HorizontalAlignment','left');

callbackstring = [...
  'global ref1;'...
  'ref1 = sscanf(get(gcbo,''String''),''%d'');'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.1 .45 .05 .05],...
              'String',sprintf('%d ',ref1),...
              'HorizontalAlignment','left','Max',1,'Callback',callbackstring);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.16 .45 .15 .05],...
              'String','Ref 2:','HorizontalAlignment','left');

callbackstring = [...
  'global ref2;'...
  'ref2 = sscanf(get(gcbo,''String''),''%d'');'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.26 .45 .05 .05],...
              'String',sprintf('%d ',ref2),...
              'HorizontalAlignment','left','Max',1,'Callback',callbackstring);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .4 .3 .05],...
              'String','Plot coils:','HorizontalAlignment','left');

callbackstring = [...
  'global plot_coils;'...
  'plot_coils = sscanf(get(gcbo,''String''),''%d'');'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.2 .4 .3 .05],...
              'String',sprintf('%d ',plot_coils),...
              'HorizontalAlignment','left','Max',1,'Callback',callbackstring);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .35 .3 .05],...
              'String','Linked coils:','HorizontalAlignment','left');

callbackstring = [...
  'global tongue_coils;'...
  'tongue_coils = sscanf(get(gcbo,''String''),''%d'');'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.2 .35 .3 .05],...
              'String',sprintf('%d ',tongue_coils),...
              'HorizontalAlignment','left','Max',1,'Callback',callbackstring);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .5 .3 .05],...
              'String','EPG palate:','HorizontalAlignment','left');

callbackstring = [...
  'global epg_pal;'...
  'epg_pal = eval(get(get(gcf,''CurrentObject''),''String''));'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.2 .5 .3 .05],...
              'String','sdepgpal','HorizontalAlignment','left','Max',1,...
              'Callback',callbackstring);

% ---------------------------------------------------------
% font names and sizes

uicontrol(gcf,'Style','frame','Units','Normal','Position',[.005 .03 .5 .29]);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .25 .25 .05],...
              'String','Font name:','HorizontalAlignment','left');

callbackstring = [...
  'h_fig = fndwin(''EMA Tools'');'...
  'h = findobj(h_fig,''Type'',''text'');'...
  'h = [h ; findobj(h_fig,''Type'',''axes'')];'...
  'list_fonts = str2mat(''Courier'',''Helvetica'');'...
  'fontname = list_fonts(get(get(gcf,''CurrentObject''),''Value''),:);'...
  'set(h,''FontName'',deblank(fontname));'];

uicontrol(gcf,'Style','popup','Units','Normal','Position',[.3 .25 .195 .05],...
              'String','Courier|Helvetica','HorizontalAlignment','left','Max',1,...
              'Callback',callbackstring);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .20 .3 .05],...
              'String','Font Size / x-axis labels:','HorizontalAlignment','left');

callbackstring = [...
  'h = findobj(fndwin(''EMA Tools''),''Type'',''axes'');'...
  'fontsize = get(get(gcf,''CurrentObject''),''String'');'...
  'for i = 1:length(h); set(get(h(i),''xlabel''),''FontSize'',str2num(fontsize)); end;'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.3 .20 .195 .05],...
              'String','11','HorizontalAlignment','left','Max',1,...
              'Callback',callbackstring);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .15 .3 .05],...
              'String','Font Size / y-axis labels:','HorizontalAlignment','left');

callbackstring = [...
  'h = findobj(fndwin(''EMA Tools''),''Type'',''axes'');'...
  'fontsize = get(get(gcf,''CurrentObject''),''String'');'...
  'for i = 1:length(h); set(get(h(i),''ylabel''),''FontSize'',str2num(fontsize)); end;'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.3 .15 .195 .05],...
              'String','11','HorizontalAlignment','left','Max',1,...
              'Callback',callbackstring);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .10 .3 .05],...
              'String','Font Size / cursor values:','HorizontalAlignment','left');

callbackstring = [...
  'h = findobj(fndwin(''EMA Tools''),''Type'',''axes'');'...
  'h1 = findobj(h,''Type'',''text'',''UserData'',1);'...
  'h2 = findobj(h,''Type'',''text'',''UserData'',2);'...
  'fontsize = get(get(gcf,''CurrentObject''),''String'');'...
  'set([h1 h2],''FontSize'',str2num(fontsize));'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.3 .10 .195 .05],...
              'String','8','HorizontalAlignment','left','Max',1,...
              'Callback',callbackstring);

uicontrol(gcf,'Style','text','Units','Normal','Position',[.01 .05 .3 .05],...
              'String','Font Size / tick marks:','HorizontalAlignment','left');

callbackstring = [...
  'h = findobj(fndwin(''EMA Tools''),''Type'',''axes'');'...
  'fontsize = get(get(gcf,''CurrentObject''),''String'');'...
  'set(h,''FontSize'',str2num(fontsize));'];

uicontrol(gcf,'Style','edit','Units','Normal','Position',[.3 .05 .195 .05],...
              'String','10','HorizontalAlignment','left','Max',1,...
              'Callback',callbackstring);


uicontrol(gcf,'Style','frame','Units','Normal','Position',[.51 .03 .485 .94],...
              'BackgroundColor',[.4 .4 .4]);  




