function demo

global aud_sr tlim h_axes
global ema_sr epg_sr
global tongue_coils

close(findobj('UserData','EMA Tools'));

ematools;

h_fig1 = fndwin('EMA Tools');

% x, from left border; y, from bottom; width; height

ssize = get(0,'ScreenSize');

set(h_fig1,'Position',[ssize(3)*.2 ssize(4)*.2 ssize(3)*.4 ssize(4)*.6]);

clc;

disp(str2mat('------------------------------',...
             'READING EXTERNAL DATA FILES',...
             '------------------------------',''));

fprintf(1,'Example: audio, EMA and EPG data simultaneously recorded during the production of the sentence ''It''s a kip again'' by a female speaker of Southern British English.\n\n');

fprintf(1,'(Data made available to me by Phil Hoole, Fiona Gibbon and Bill Hardcastle.)\n');

r = input('\nReady to load audio signal (type ENTER to continue): ');

loadaud('fay001.aud');

r = input('\nReady to load EMA signal (type ENTER to continue): ');

loadema('fay001.ema');

r = input('\nReady to load EPG signal (type ENTER to continue): ');

loadepg('fay001.epg');

global ema epg;

r = input('\nDone. Type ENTER to continue: ');

fprintf(1,'\n');

disp(str2mat('------------------------------',...
             'EDITING FUNCTIONS',...
             '------------------------------',''));

r = input('Now move the left cursor to the right (type ENTER to continue): ');

for i = 1:6
  crsrmove(1,.02);
end

r = input('\nNow move the right cursor to the right (type ENTER to continue): ');

for i = 1:6
  crsrmove(2,.02);
end

r = input('\nNow expand the signal between the two cursors (type ENTER to continue): ');

zoomx('in');

r = input('\nNow get back to the original display (type ENTER to continue): ');

zoomx('out');

r = input('\nNow activate Track #2, clear that track, and display the y coordinate of the coil attached to the tongue tip (type ENTER to continue): ');

activate(2);

r = input('\nTrack activated... (type ENTER to continue): ');

clrtrack(2);

r = input('\nTrack cleared... (type ENTER to continue): ');

y1 = get(findobj('Label','y1'),'UserData');

t = tscale(y1,ema_sr);

dispsig(y1,t,'tt/y',2,'TIM');

r = input('\nNow activate Track #3, clear that track, and display the y coordinate of the coil attached to the front part of the tongue dorsum (type ENTER to continue): ');

activate(3);

r = input('\nTrack activated... (type ENTER to continue): ');

clrtrack(3);

r = input('\nTrack cleared.... (type ENTER to continue): ');

y3 = get(findobj('Label','y3'),'UserData');

t = tscale(y3,ema_sr);

dispsig(y3,t,'td/y',3,'TIM');

r = input('\nDone. Type ENTER to continue: ');

fprintf(1,'\n');

disp(str2mat('------------------------------',...
             'DATA PROCESSING FUNCTIONS',...
             '------------------------------',''));

r = input('Now smooth this signal (quadratic spline) (type ENTER to continue): ');

[y,t2] = smooth(y3,t,11);

dispsig(y,t2,'td/y',3,'TIM');

r = input('\nNow compute the velocity of the smoothed signal and display the result in Track #4 (type ENTER to continue): ');

[yy,t2] = deriv(y3,t,'vel');

[yy,t2] = smooth(yy,t2,11);

dispsig(yy,t2,'td/y vel.',4,'TIM');

r = input('\nNow compute the sum of contacts in the back part of the palate (last three rows) and display the result in Track #5 (type ENTER to continue): ');

vel = epgindex(epg,'VEL');

t = tscale(vel,epg_sr);

dispsig(vel,t,'VEL',5,'TIM');

r = input('\nNow compute the tangential velocity of the coil attached to the front part of the dorsum and display the result in Track #6 (type ENTER to continue): ');

x3 = get(findobj('Label','x3'),'UserData');

t = tscale(x3,ema_sr);

[z,t2] = deriv2d(x3,y3,t,'tgv');

dispsig(z,t2,'td tg. vel.',6,'TIM');

r = input('\nDone. Type ENTER to continue: ');

fprintf(1,'\n');

disp(str2mat('------------------------------',...
             'ANNOTATING FUNCTIONS',...
             '------------------------------',''));

r = input('Now move the left cursor to the acoustic offset of schwa in ''a kip'' and put a marker at this point (type ENTER to continue): ');

t1 = crsrloc(1);

delta_t = .884 - t1;

crsrmove(1,delta_t);

mrkrmake(1);

r = input('\nNow move the right cursor to the acoustic release of /k/ in ''a kip'' and put a marker at this point (type ENTER to continue): ');

t2 = crsrloc(2);

delta_t = .964 - t2;

crsrmove(2,delta_t);

mrkrmake(2);

crsrmove(1,-.05);
crsrmove(2,.05);

zoomx('in');

r = input('\nDone. Type ENTER to continue: ');

fprintf(1,'\n');

disp(str2mat('------------------------------',...
             'SOME OF THE DISPLAYS AVAILABLE',...
             '------------------------------',''));

r = input('Now show the positions of the EMA coils in the x/y plane associated with the two cursors (type ENTER to continue): ');

tongue_coils = 1:4;

emafig;

h_fig2 = fndwin('EMA Prof.');

% x, from left border; y, from bottom; width; height

set(h_fig2,'Position',[ssize(3)*.62 ssize(4)*.6 ssize(3)*.25 ssize(4)*.2]);

r = input('\nNow show the trajectories of the EMA coils in the x-y plane between the two cursors (type ENTER to continue): ');

ematrj;

h_fig3 = fndwin('EMA traj.');

% x, from left border; y, from bottom; width; height

set(h_fig3,'Position',[ssize(3)*.62 ssize(4)*.4 ssize(3)*.25 ssize(4)*.2]);

r = input('\nNow superimpose the two EMA displays on each other (type ENTER to continue): ');

copyfig(h_fig2,'n');
copyfig(h_fig3,'a');

set(gcf,'Position',[ssize(3)*.65 ssize(4)*.4 ssize(3)*.25 ssize(4)*.2]);

r = input('\nNow show the EPG patterns associated with the two cursors (type ENTER to continue): ');

epgfig;

h_fig4 = fndwin('EPG');

% x, from left border; y, from bottom; width; height

set(h_fig4,'Position',[ssize(3)*.62 ssize(4)*.2 ssize(3)*.25 ssize(4)*.2]);

r = input('\nNow show the FFTs associated with the two cursors (type ENTER to continue): ');

fftfig(256);

h_fig5 = fndwin('FFT');

set(h_fig5,'Position',[ssize(3)*.2 ssize(4)*.2 ssize(3)*.4 ssize(4)*.2]);

r = input('\nNow move the left cursor from left to right (type ENTER to continue): ');

movies

r = input('\nDo it again (type ENTER to continue): ');

movies

r = input('\nDone. Type ENTER to continue: ');

fprintf(1,'\n');

disp(str2mat('------------------------------',...
             'LOCATING ARTICULATORY EVENTS AUTOMATICALLY',...
             '------------------------------',''));

r = input('Now find first EPG velar closure to the right of the left cursor (type ENTER to continue): ');

epglmark('VEL_CLOS');

r = input('\nNow find EPG velar release (type ENTER to continue): ');

epglmark('VEL_REL');


fprintf(1,'\nEnd of the demo.\n');
