function h_lines = el2sig (x,y)

% EL2SIG: compute and display 2-sigma ellipse for data set with
%        x as horizontal coord. and y as vertical coord.
%        also compute phi, the angle of the first principal component
%        relative to the vertical axis in radians.
%
%        Written for the Edinburgh workshop on EMA, 27 June 96

%        N. Nguyen, June 1996

x = x(:);
y = y(:);

[U,D] = eig(cov(x,y));			% eigenvectors/eigenvalues of
					% covariance matrix

[D,i] = sort(diag(D));

D = flipud(D);				% sort eigenvalues in decreasing order

U = U(:,[i(2) i(1)]);			% sort eigenvectors accordingly

a = 2 * sqrt(D(1));			% (2 * st. dev.) for axis 1
b = 2 * sqrt(D(2));			% (2 * st. dev.) for axis 2

xmoy = mean(x);				% coordinates of center of gravity
ymoy = mean(y);

if U(1,2) < 0
  U(:,1) = -U(:,1);
end

phi = angle(U(1,1) + sqrt(-1)*U(2,1)) - pi/2;

U = U';
U = ([a 0 ; 0 b] * U);			%elongation des vecteurs propres

U1 = [1 0 ; 0 0] * U;
U1 = U1 - flipud(U1);

U2 = [0 0 ; 0 1] * U;
U2 = U2 - flipud(U2);

U1 = ([1 1]' * [xmoy ymoy]) + U1;	%centrage des vecteurs propres
U2 = ([1 1]' * [xmoy ymoy]) + U2;

hold on

h_lines(1) = plot(U1(:,1),U1(:,2));
h_lines(2) = plot(U2(:,1),U2(:,2));

axis('equal')

alpha = 0:.01:2*pi;			%construction d'un cercle
x = cos(alpha)';
y = sin(alpha)';

M = [x y] * U;				%transformation du cercle en ellipse

M = M + (ones(size(M)) * [xmoy 0; 0 ymoy]);	%centrage de l'ellipse

h_lines(3) = plot(M(:,1),M(:,2));

