function emafig

% EMAFIG: create/refresh EMA window.
%
%	In this window are displayed the x and y coordinates of
%	the coils at the cursors' locations along the time axis.
%	The subject's palate midsagittal contour is also shown.
%
%	See also: PLOTEMA, PLOTEMA3.

%	N. Nguyen, July 95, 18/09/95

global ema ema_pal tongue_coils plot_coils ema_prof
global ref1 ref2

if ~exist('ema')
  fprintf(1,'\nEMA data not available.\n');
  return;
end

color1 = 'red';
color2 = [0, 0.5, 0];
%plot_coils = [1 2 3 4 5 9 10 11 12 13 14 15 19 20];
%Now located in runema.m aaw Oct 98

ncol = size(ema,2);
ncoils = ncol / 2;

x = ema(:,1:ncoils);
y = ema(:,ncoils+1:ncol);
%ema_prof = ema(:,plot_coils);
%ema_prof = ema;
paloriginx = mean(ema(:,ref1));
paloriginy = mean(ema(:,ref1+ncoils));
tmp =ones(size(ema_pal,1),1);
palorigin = [paloriginx*tmp paloriginy*tmp];
prof_ema_pal = ema_pal + palorigin;
x_prof = x(:,plot_coils);
y_prof = y(:,plot_coils);

xmax = max(max(x_prof));
xmin = min(min(x_prof));
ymax = max(max(y_prof));
ymin = min(min(y_prof));

xmax = max([xmax ; max(prof_ema_pal(:,1))]) + 2;
xmin = min([xmin ; min(prof_ema_pal(:,1))]) - 2;
ymax = max([ymax ; max(prof_ema_pal(:,2))]) + 2;
ymin = min([ymin ; min(prof_ema_pal(:,2))]) - 2;

delta_x = xmax - xmin;
delta_y = ymax - ymin;

%if delta_x > delta_y
%  ymin = ymax - delta_x;
%else
%  xmax = xmin + delta_y;
%end

xmid = (xmax - xmin)/2;
ymid = (ymax - ymin)/2;

string = sprintf('%9.3f %9.3f',xmid,ymid);
%fprintf('%d %d %d %d \n',xmin, xmax, ymin, ymax);

h_fig = findobj('Name','EMA prof.');

if ~isempty(h_fig)

  figure(h_fig);

  h_axes = findobj(h_fig,'Type','axes');

  delete(findobj(h_fig,'UserData','EMA1a'));
  delete(findobj(h_fig,'UserData','EMA2a'));
  delete(findobj(h_fig,'UserData','EMA1b'));
  delete(findobj(h_fig,'UserData','EMA2b'));

  axes(h_axes);

  if exist('prof_ema_pal')

    line('Color','k','XData',prof_ema_pal(:,1),'YData',prof_ema_pal(:,2));

  end

  set(gca,'Box','on','XLim',[xmin xmax],'YLim',[ymin ymax]);

  axis equal;
% ------------------------------------------------------------------------------
% main menu

M = uimenu(h_fig,'Label','Main');

uimenu(M,'Label','Smooth traces','Callback','loadaud;');

% plots a single point line (ie a point) per column of the matrices in XDATA and% YDATA ) marked with a o based on plot_data
  line('Erasemode','xor','Color',color1,'Marker','o',...
       'LineStyle','none','XData',x_prof(1,:),'YData',y_prof(1,:),...
       'UserData','EMA1a');

  line('Erasemode','xor','Color',color2,'Marker','o',...
       'LineStyle','none','XData',x_prof(1,:),'YData',y_prof(1,:),...
       'UserData','EMA2a');

  line('Erasemode','xor','Color',color1,'Marker','none',...
       'LineStyle','-','XData',x(1,tongue_coils),...
       'YData',y(1,tongue_coils),'UserData','EMA1b');

  line('Erasemode','xor','Color',color2,'Marker','none',...
       'LineStyle','-','XData',x(1,tongue_coils),...
       'YData',y(1,tongue_coils),'UserData','EMA2b');

  return;

end

h_fig = figure;

set(h_fig,'Name','EMA Prof.','NumberTitle','off','UserData','EMA Tools', 'position', [0,0,400,300]);

if exist('prof_ema_pal')

  h_line = plot(prof_ema_pal(:,1),prof_ema_pal(:,2),'k');

  set(h_line,'UserData','PAL');
  
end

set(gca,'Box','on','NextPlot','add','FontName','Courier',...
        'FontSize',10,'XLim',[xmin xmax],'YLim',[ymin ymax]);

axis equal;

grid on

set(get(gca,'xlabel'),'FontName','Courier','FontSize',11,...
                      'String','x (mm)');
 
set(get(gca,'ylabel'),'FontName','Courier','FontSize',11,...
                      'String','y (mm)');

line('Erasemode','xor','Color',color1,'Marker','o',...
     'LineStyle','none','XData',x_prof(1,:),'YData',y_prof(1,:),...
     'UserData','EMA1a');

line('Erasemode','xor','Color',color2,'Marker','o',...
     'LineStyle','none','XData',x_prof(1,:),'YData',y_prof(1,:),...
     'UserData','EMA2a');

line('Erasemode','xor','Color',color1,'Marker','none',...
     'LineStyle','-','XData',x(1,tongue_coils),...
     'YData',y(1,tongue_coils),'UserData','EMA1b');

line('Erasemode','xor','Color',color2,'Marker','none',...
     'LineStyle','-','XData',x(1,tongue_coils),...
     'YData',y(1,tongue_coils),'UserData','EMA2b');
