function ematools(ident)

% EMATOOLS: create menus in the main window.
%
%	See also: MKTRACKS.

%	N. Nguyen, July 96

%global FILEDIR NTRACKS AUDFILEEXT LARFILEEXT EPGFILEEXT
%global aud_sr lar_sr ema_sr epg_sr
%global ema_pal epg_pal
%global tongue_coils
%global ncoils
%global h_axes h_lines h_crsr h_val
%global tlim tmin tmax
global NTRACKS
h_fig = findobj('Tag','EmaTools-Waveform','Userdata',ident);

if isempty(h_fig)
   figure('MenuBar', 'None')
else
  fprintf(1,'\nWarning: EMATOOLS is already running.\n');
  figure('MenuBar', 'None')
  %return;
end


% ------------------------------------------------------------------------------
% main menu

set(gcf,'Name','EMA Tools','NumberTitle','off','UserData',ident, ...
'Position', [300, 0, 450, 500], 'PaperType','A4','Tag','EmaTools-Waveform','Color','w');

M = uimenu('Label','File');

uimenu(M,'Label','Load acoustic file','Callback','loadaud;');

uimenu(M,'Label','Load laryngograph file','Callback','loadlar;');

uimenu(M,'Label','Load EMA file','Callback','loadema;');

uimenu(M,'Label','Load EPG file','Callback','loadepg;');

uimenu(M,'Label','Load Markers','Accelerator','l','Callback','mrkrload;',...
         'Separator','on');

uimenu(M,'Label','Save Markers','Accelerator','s','Callback','mrkrsave;');

uimenu(M,'Label','Save Value','Callback','saveval;');

uimenu(M,'Label','Save EPG Pattern','Callback','saveepg;');

uimenu(M,'label','Copy Fig.','Callback','copyfig;','Separator','on');

uimenu(M,'label','Save Fig.','Callback','savefig;');

uimenu(M,'label','Load Fig.','Callback','loadfig;');

%NO EXPLICIT PRINT OPTION REQUIRED IN MATLAB VER 5
%callbackstring = [...
%  'print_cmd = get(gcbo,''UserData'');'...
%  'printfig(print_cmd);'];

%uimenu(M,'label','Print','Accelerator','p','Callback',callbackstring,...
%         'UserData',str2mat('orient portrait','print -dpsc2 -Pqmc1'));

%uimenu(M,'label','Print Setup','Callback','prsetup;');
callbackstring = [...
'set(findobj(''Type'',''uicontrol''),''Visible'',''off'');',...
'set(findobj(''Type'',''text'',''UserData'',2),''Visible'',''off'');',...
'set(findobj(''Type'',''text'',''UserData'',1),''Visible'',''off'');'];
uimenu(M,'label','Hide clutter','Callback',callbackstring,'Separator','on');
callbackstring = [...
'set(findobj(''Type'',''uicontrol''),''Visible'',''on'');',...
'set(findobj(''Type'',''text'',''UserData'',2),''Visible'',''on'');',...
'set(findobj(''Type'',''text'',''UserData'',1),''Visible'',''on'');'];
uimenu(M,'label','Restore clutter','Callback',callbackstring);

uimenu(M,'Label','Config.','Callback','config;','Separator','on');

callbackstring = 'close(findobj(''UserData'',''EMA Tools''));';

uimenu(M,'Label','Quit','Accelerator','q','Callback',callbackstring,...
         'Separator','on');

% ------------------------------------------------------------------------------
% edit menu

M = uimenu('Label','Edit');

callbackstring = [...
  %'global h_lines;'...
  'h_axes = findobj(findobj(0,''Tag'',''EmaTools-Waveform''),''Type'',''axes'');'...
  'h_lines = findobj(h_axes,''Tag'',''WaveForm'',''Selected'',''On'');'...
  'ntrack = fndtrack(''ACTIVE'');'...
  'if isempty(ntrack); return; end;'...
  'y = get(h_lines(ntrack),''YData'');'...
  't = get(h_lines(ntrack),''XData'');'...
  'editsig(y,t);'];

uimenu(M,'Label','Edit Signal','Callback',callbackstring);

uimenu(M,'Label','Add track','Callback','addtrack');

uimenu(M,'Label','Delete track','Callback','deltrack');

uimenu(M,'Label','Clear Track','Accelerator','c',...
         'Callback','clrtrack');

callbackstring = [...
  'global NTRACKS;'...
  'for i = 1:NTRACKS; clrtrack(h_axes{1},i); end;'];

uimenu(M,'Label','Clear All','Callback',callbackstring);

uimenu(M,'Label','Create Marker','Accelerator','m',...
         'Callback','mrkrmake;','Separator','on');

uimenu(M,'Label','Sort Markers','Callback','mrkrsort;');

uimenu(M,'Label','Move Marker','Callback','mrkrmove;');

uimenu(M,'Label','Delete Marker','Accelerator','d',...
         'Callback','mrkrdel');

uimenu(M,'Label','Find Extremum','Accelerator','e',...
         'Callback','extremum','Separator','on'); 

uimenu(M,'Label','Find abs. min.','Accelerator','i',...
         'Callback','absmin');

uimenu(M,'Label','Find EPG alv. clos.','Callback','epglmark(''ALV_CLOS'');');

uimenu(M,'Label','Find EPG alv. rel.','Callback','epglmark(''ALV_REL'');');

uimenu(M,'Label','Find EPG vel. clos.','Callback','epglmark(''VEL_CLOS'');');

uimenu(M,'Label','Find EPG vel. rel.','Callback','epglmark(''VEL_REL'');');

uimenu(M,'Label','Vert. zoom / in','Callback','zoomy(''in'')');

uimenu(M,'Label','Vert. zoom / out','Callback','zoomy(''full'')');

uimenu(M,'Label','Save EMA to ASCII file','Callback','zoomy(''full'')');

uimenu(M,'Label','Movie','Accelerator','b','Separator','on',...
         'Callback','movies');

% ------------------------------------------------------------------------------
% Tools menu

M = uimenu('Label','Tools');

callbackstring1 = [...
  'h_audio = findobj(''Tag'',''AUD'');'...
  'if isempty(h_audio); return; end;'...
  'A = get(h_audio,''YData''); t = get(h_audio,''XData'');'];

callbackstring2 = [...
   callbackstring1...
  '[y,t2] = rmsint(A,t,80,160); dispsig(y,t2,''RMS Int. (dB)'');'];

uimenu(M,'Label','RMS Intensity','Callback',callbackstring2);

callbackstring2 = [...
   callbackstring1...
  '[y,t2] = zercross(A,t,80,160); dispsig(y,t2,''0-crossing rate (/s)'');'];

uimenu(M,'Label','0-Crossing Rate','Callback',callbackstring2);

uimenu(M,'Label','Resample','Callback','resampletrack;');

uimenu(M,'Label','Play Between Cursors','Accelerator','z',...
         'Callback','sndplay(''w'')','Separator','on');

uimenu(M,'Label','Play Entire Window','Accelerator','f',...
         'Callback','sndplay(''f'')');

% ------------------------------------------------------------------------------
% EMA menu

M = uimenu('Label','EMA');

% ------------------------------------------------------------------------------
% EPG menu

M = uimenu('Label','EPG');

callbackstring = [...
  'global epg epg_sr;'...
  'if isempty(epg);'...
  'fprintf(1,''\nEPG data not available.\n''); return; end;'...
  'label = get(gcbo,''Label'');'...
  'y = epgindex(epg,label);'...
  't = tscale(y,epg_sr);'...
  'dispsig(y,t,label);'];

uimenu(M,'Label','TOT','Callback',callbackstring);

uimenu(M,'Label','ANT','Callback',callbackstring);

uimenu(M,'Label','PST','Callback',callbackstring);

uimenu(M,'Label','ALV','Callback',callbackstring);

uimenu(M,'Label','PAL','Callback',callbackstring);

uimenu(M,'Label','VEL','Callback',callbackstring);

uimenu(M,'Label','COG','Callback',callbackstring);

uimenu(M,'Label','LAT','Callback',callbackstring);

uimenu(M,'Label','Rows 1-2','Callback',callbackstring);

uimenu(M,'Label','Row 8','Callback',callbackstring);

% ------------------------------------------------------------------------------
% Transform menu

M = uimenu('Label','Transforms');

callbackstring1 = [...
  %'global h_axes h_lines;'...
  'h_axes = findobj(findobj(0,''Tag'',''EmaTools-Waveform''),''Type'',''axes'');'...
  'h_lines = findobj(h_axes,''Tag'',''WaveForm'');'...
  'ntrack = fndtrack(''ACTIVE'');'...
  'if isempty(ntrack); return; end;'...
  'y = get(h_lines(ntrack),''YData'');'...
  't1 = get(h_lines(ntrack),''XData'');'...
  'label = get(get(h_axes(ntrack),''ylabel''),''String'');'];

callbackstring2 = [...
  callbackstring1...
  'ntrack2 = fndtrack(''FREE'');'...
  'if isempty(ntrack2); ntrack2 = ntrack;'...
  'end;'...
  'label = [''vel '' label];'...
  '[yy,t2] = deriv(y,t1,''vel'');'...
  'dispsig(yy,t2,label,ntrack2);'];

uimenu(M,'Label','Velocity','Callback',callbackstring2);

callbackstring2 = [...
  callbackstring1...
  'ntrack2 = fndtrack(''FREE'');'...
  'if isempty(ntrack2); ntrack2 = ntrack;'...
  'end;'...
  'label = [''acc '' label];'...
  '[yy,t2] = deriv(y,t1,''acc'');'...
  'dispsig(yy,t2,label,ntrack2);'];

uimenu(M,'Label','Acceleration','Callback',callbackstring2);

callbackstring2 = [...
  callbackstring1...
  'ntrack2 = fndtrack(''FREE'');'...
  'if isempty(ntrack2);'...
  'ntrack2 = ntrack; end;'...
  'label = [label '' - sm''];'...
  '[yy,t2] = smooth(y,t1,11);'...
  'dispsig(yy,t2,label,ntrack2);'];

uimenu(M,'Label','Smoothing','Callback',callbackstring2);

callbackstring2 = [...
   callbackstring1...
  '[yy,t2] = rmsint(y,t1,32,64);'...
  ' dispsig(yy,t2,''RMS Int. (dB)'');'];

uimenu(M,'Label','RMS Intensity','Callback',callbackstring2);

callbackstring = [...
  %'global h_axes h_lines;'...
  'h_axes = findobj(findobj(0,''Tag'',''EmaTools-Waveform''),''Type'',''axes'');'...
  'h_lines = findobj(h_axes,''Tag'',''WaveForm'');'...
  '[ntrack1,ntrack2] = activ2;'...
  'y1 = get(h_lines(ntrack1),''YData'');'...
  't1 = get(h_lines(ntrack1),''XData'');'...
  'y2 = get(h_lines(ntrack2),''YData'');'...
  '[yy,t2] = deriv2d(y1,y2,t1,''dis'');'...
  'dispsig(yy,t2,''integr. dist.'');'];

uimenu(M,'Label','Integrated Distance','Callback',callbackstring);

callbackstring = [...
  %'global h_axes h_lines;'...
  'h_axes = findobj(findobj(0,''Tag'',''EmaTools-Waveform''),''Type'',''axes'');'...
  'h_lines = findobj(h_axes,''Tag'',''WaveForm'');'...
  '[ntrack1,ntrack2] = activ2;'...
  'y1 = get(h_lines(ntrack1),''YData'');'...
  't1 = get(h_lines(ntrack1),''XData'');'...
  'y2 = get(h_lines(ntrack2),''YData'');'...
  '[yy,t2] = deriv2d(y1,y2,t1,''tgv'');'...
  'dispsig(yy,t2,''tang. vel.'');'];

uimenu(M,'Label','Tangential Velocity','Callback',callbackstring);

callbackstring = [...
  %'global h_axes h_lines;'...
  'h_axes = findobj(findobj(0,''Tag'',''EmaTools-Waveform''),''Type'',''axes'');'...
  'h_lines = findobj(h_axes,''Tag'',''WaveForm'');'...
  '[ntrack1,ntrack2] = activ2;'...
  'y1 = get(h_lines(ntrack1),''YData'');'...
  't1 = get(h_lines(ntrack1),''XData'');'...
  'y2 = get(h_lines(ntrack2),''YData'');'...
  '[ntrack3,ntrack4] = activ2;'...
  'y3 = get(h_lines(ntrack3),''YData'');'...
  'y4 = get(h_lines(ntrack4),''YData'');'...
  '[yy,t2] = absdist(y1,y2,y3,y4,t1);'...
  'dispsig(yy,t2,''scal. dist.'');'];
 
uimenu(M,'Label','distance between tracks','Callback',callbackstring);
 

% ------------------------------------------------------------------------------
% Displays menu

M = uimenu('Label','Displays');
callbackstring =[...
      'ematools(2);'];
uimenu(M,'Label','Waveform','Callback',callbackstring);

uimenu(M,'Label','EMA Prof.','Callback','emafig;');

%uimenu(M,'Label','EMA 3D','Callback','plotema3;');

uimenu(M,'Label','EMA traj.','Callback','ematrj;');

uimenu(M,'Label','FFT','Callback','fftfig(256);');
uimenu(M,'Label','Spectrogram','Callback','specfig;');
uimenu(M,'Label','2-s ellipse','Callback','catchpts;');

uimenu(M,'Label','EPG pat.','Callback','epgfig;','Separator','on');

uimenu(M,'Label','EPG printout','Callback','epgprn;');

%uimenu(M,'Label','Phase portrait','Callback','phaseprt;','Separator','on');

% ------------------------------------------------------------------------------
% create control buttons along top

top = 0.9;
t_bottom = top + ((1 - top) * .25);
t_left = 0.1;
t_height = (1 - top) * .25;
b_height = (1 - top) * .5;
b_left = 0.1;
b_bottom = top + ((1 - top) * .5);
b_width = b_height;
color1 = 'red';
color2 = [0, 0.5, 0];
 
callbackstring = ...
  ['t = crsrmove(1,-.001);'...
   'plotfft(''FFT1'',t);'...
   'plotepg(''EPG1'',t);'...
   'plotema(''EMA1'',t);'];
 
handle = uicontrol('Style','Pushbutton','ForegroundColor',color1,...
           'Units','normal','Position',[b_left b_bottom b_width b_height],...
           'String','<','Callback','cursor dec1');

callbackstring = ...
  ['t = crsrmove(1,.001);'...
   'plotfft(''FFT1'',t);'...
   'plotepg(''EPG1'',t);'...
   'plotema(''EMA1'',t);'];

handle = uicontrol('Style','Pushbutton','ForegroundColor',color1,...
   			'Units','normal','Position',...
				[b_left+b_width b_bottom b_width b_height],...
            'String','>','Callback','cursor inc1');
         
handle = uicontrol('Style','Text','ForegroundColor',color1,...
   			'BackgroundColor','w','Tag','CursorTime',...
   			'UserData',1,...
				'Units','normal','Position',...
				[t_left t_bottom 8*b_width t_height],...
           	'String','Time(s)');
%handle = uicontrol('Style','Text','ForegroundColor',color1,...
%   			'BackgroundColor','w','Tag','CursorAmp',...
%   			'UserData',1,...
%				'Units','normal','Position',...
%				[b_left+4.6*b_width b_bottom 2*b_width b_height],...
%           	'String','Amplitude');

b_left = 0.1 + (0.85)/2 - 1.5*b_width;
t_left = 0.1 + (0.85)/2;

handle = uicontrol('Style','Pushbutton','Units','normal',...
           'Position',[b_left b_bottom b_width b_height],...
           'String','> <','Callback','zoomx(''in'')');

handle = uicontrol('Style','Pushbutton','Units','normal',...
           'Position',[b_left+b_width b_bottom b_width b_height],...
           'String','< >','Callback','zoomx(''out'')');

handle = uicontrol('Style','Pushbutton','Units','normal',...
           'Position',[b_left+b_width*2 b_bottom b_width b_height],...
           'String','[ ]','Callback','zoomx(''full'')');

b_left = 0.1 + 0.85 - b_width*2;

%handle = uicontrol('Style','Text','ForegroundColor',color2,...
%   			'BackgroundColor','w','Tag','CursorAmp',...
%   			'UserData',2,...
%				'Units','normal','Position',...
%				[b_left-2.4*b_width b_bottom 2*b_width b_height],...
%           	'String','Amplitude');
handle = uicontrol('Style','Text','ForegroundColor',color2,...
   			'BackgroundColor','w','Tag','CursorTime',...
   			'UserData',2,...
				'Units','normal','Position',...
				[t_left t_bottom 8*b_width t_height],...
           	'String','Time(s)');

callbackstring = ...
  ['t = crsrmove(2,-.001);'...
   'plotfft(''FFT2'',t);'...
   'plotepg(''EPG2'',t);'...
   'plotema(''EMA2'',t);'];
 
handle = uicontrol('Style','Pushbutton','ForegroundColor',color2,...
           'Units','normal','Position',[b_left b_bottom b_width b_height],...
           'String','<','Callback','cursor dec2');

callbackstring = ...
  ['t = crsrmove(2,.001);'...
   'plotfft(''FFT2'',t);'...
   'plotepg(''EPG2'',t);'...
   'plotema(''EMA2'',t);'];

handle = uicontrol('Style','Pushbutton','ForegroundColor',color2,...
           'Units','normal','Position',[b_left+b_width b_bottom...
             b_width b_height],'String','>','Callback','cursor inc2');
% ------------------------------------------------------------------------------
NTRACKS = 9;
mktracks(NTRACKS,'EmaTools-Waveform');
activate(2);










