function ematrj

% EMATRJ: print trajectory in the x-y plane for each coil.
%
%	See also: EMAFIG, PLOTEMA

%	N. Nguyen, 21/02/96
%  	modified A. Wrench 29/03/99

global ema ema_sm ema_sr ema_pal
global plot_coils tongue_coils ema_prof
global pal_sm
global pal

if ~exist('ema')
  fprintf(1,'\nEMA data not available.\n');
  return;
end

h_fig1 = findobj('Name','EMA Prof.');

if isempty(h_fig1)
  fprintf(1,'\nEMA Prof. window should be opened first.\n');
  return;
end

t1 = crsrloc(1);
t2 = crsrloc(2);

if t2 < t1
  dummy = t1;
  t1 = t2;
  t2 = dummy;
end

samp1 = floor(t1 * ema_sr) + 1;
samp2 = floor(t2 * ema_sr) + 1;

nsamp = samp2 - samp1 + 1;

h_mrkr = findobj('Tag','MarkerLine');

if ~isempty(h_mrkr);

  h_axes = get(h_mrkr(1),'Parent');

  h_mrkr =  findobj(h_axes,'Tag','MarkerLine');

  j = 1;

  for i = 1:length(h_mrkr)

    t = get(h_mrkr(i),'XData');
    t = t(1);

    if t >= t1 & t <= t2
      marked_samp(j) = floor(t * ema_sr) - samp1 ;%+ 2;
      j = j + 1;
    end

  end

  marked_samp = sort(marked_samp);

end

h_pal = findobj(h_fig1,'UserData','PAL');

pal = [get(h_pal,'XData')' get(h_pal,'YData')'];

h_axes1 = findobj(h_fig1,'Type','axes');

h_fig2 = findobj('Type','figure','Name','EMA traj.');

if isempty(h_fig2)

  h_fig2 = figure;
  set(h_fig2,'Name','EMA traj.','NumberTitle','off','UserData','EMA Tools',...
'position',[0,400,400,300]);
  h_axes2 = copyobj(h_axes1,h_fig2);
  delete(get(h_axes2,'Children'));
  %set(h_axes2,'Parent',h_fig2);
  M = uimenu(h_fig2, 'label', 'main');
callbackstring = [...
  'global ema ema_sm pal pal_sm;'...
  'ema_sm = smooth2D(ema,11);'...
  'pal_sm = smooth2D(pal,11);'...
  'ematrj;'];

  uimenu(M, 'label', 'Smooth plot', 'Callback', callbackstring);

else

  figure(h_fig2);
  h_axes2 = gca;
  delete(get(h_axes2,'Children'));

end

if isempty(pal_sm)
    pal_plot = pal;
else
    pal_plot = pal_sm;
end

if isempty(ema_sm)
    ema_plot = ema;
else
    ema_plot = ema_sm;
end

ncoord = size(ema_plot,2);
ncoils = ncoord/2;

x = ema_plot(samp1:samp2,1:ncoils);
y = ema_plot(samp1:samp2,ncoils+1:ncoord);

x_trj = x(:,plot_coils);
y_trj = y(:,plot_coils);

plot(pal_plot(:,1),pal_plot(:,2));

hold on;

plot(x_trj,y_trj);

plot(x_trj(1,:)',y_trj(1,:)','o');

if exist('marked_samp')

  for i = 1:length(marked_samp)

%    for j = 1:4

      %h_text = text(x_trj(marked_samp(i),j),y_trj(marked_samp(i),j),num2str(i));
      line('Erasemode','xor','Marker','none',...
       'LineStyle','-','XData',x(marked_samp(i),tongue_coils),...
       'YData',y(marked_samp(i),tongue_coils));

%      set(h_text,'FontName','Courier','FontSize',8,...
%          'VerticalAlignment','middle','HorizontalAlignment','center');

%    end

  end

end
