function epgfig

% EPGFIG: create/refresh EPG window.
%
%       In this window are displayed the EPG patterns corresponding
%	to the cursors' locations along the time axis.
 
%       N. Nguyen, July 95, 18/09/9

global epg epg_pal;

if ~exist('epg')
  fprintf(1,'\nEPG data not available.\n');
  return;
end

color1 = 'red';
color2 = [0,0.5,0];

if ~exist('epg_pal')

  M = (1:8)' * ones(1,8);
  x = reshape(M,64,1);
  y = flipud(reshape(M',64,1));
  x([1 8]) = [];
  y([1 8]) = [];
  epg_pal = [x y];

else

  x = epg_pal(:,1);
  y = -epg_pal(:,2);

end

h_fig = findobj('Name','EPG');

if isempty(h_fig)

  h_fig = figure;

  set(h_fig,'Name','EPG','NumberTitle','off','UserData','EMA Tools','position',[50,300,200,100]);

  h1 = subplot(1,2,1);

  set(gca,'Box','off','NextPlot','add','XTick',[],'YTick',[]);

  line('Color',color1,'LineStyle','.','MarkerSize',8,...
       'XData',x,'YData',y);

  line('Erasemode','xor','Color',color1,'LineStyle','.',...
       'MarkerSize',8,'XData',[],'YData',[],'UserData','EPG1');

  line('Erasemode','xor','Color',color1,'LineStyle','.',...
       'MarkerSize',20,'XData',[],'YData',[],'UserData','EPG1');

  axis equal;
  axis off;

  h2 = subplot(1,2,2);

  set(gca,'Box','off','NextPlot','add','XTick',[],'YTick',[]);

  line('Color',color2,'LineStyle','.','MarkerSize',8,...
       'XData',x,'YData',y);

  line('Erasemode','xor','Color',color2,'LineStyle','.',...
       'MarkerSize',8,'XData',[],'YData',[],'UserData','EPG2');

  line('Erasemode','xor','Color',color2,'LineStyle','.',...
       'MarkerSize',20,'XData',[],'YData',[],'UserData','EPG2');

  axis equal;
  axis off;

else

  set(findobj(h_fig,'UserData','EPG1'),'XData',[],'YData',[]);

  set(findobj(h_fig,'UserData','EPG2'),'XData',[],'YData',[]);

end

