function index = epgindex(epg,index_name)

% EPGINDEX: compute the specified EPG index.
%
%	TOT: total sum of contacts over the whole surface of the palate.
%	ANT: sum of contacts in the front part of the palate (first 4 rows).
%	PST: sum of contacts in the back part of the palate (last 4 rows).
%       ALV: sum of contacts, rows 1-3.
%       PAL: sum of contacts, rows 4-5.
%       VEL: sum of contacts, rows 6-8.
%	COG: center of gravity along the sagittal axis.
%	LAT: degree of lateral asymmetry.
%
%	See also: EPGPLOT.

%	N. Nguyen, July 95, 18/09/95

pal = [NaN   1   2   3   4   5   6 NaN;
         7   8   9  10  11  12  13  14;
        15  16  17  18  19  20  21  22;
        23  24  25  26  27  28  29  30;
        31  32  33  34  35  36  37  38;
        39  40  41  42  43  44  45  46;
        47  48  49  50  51  52  53  54;
        55  56  57  58  59  60  61  62];

epg = epg';

if strcmp(index_name,'TOT')

  index = sum(epg);

elseif strcmp(index_name,'ANT')

  index = sum(epg(1:30,:));

elseif strcmp(index_name,'PST')

  index = sum(epg(31:62,:));

elseif strcmp(index_name,'ALV')

  index = sum(epg(1:22,:));

elseif strcmp(index_name,'PAL')

  index = sum(epg(23:38,:));

elseif strcmp(index_name,'VEL')

  index = sum(epg(39:62,:));

elseif strcmp(index_name,'COG')

  S = sum(epg);

  P = [sum(epg(1:6,:)) ; sum(epg(7:14,:)) ; sum(epg(15:22,:)) ; ...
       sum(epg(23:30,:)) ; sum(epg(31:38,:)) ; sum(epg(39:46,:)) ; ...
       sum(epg(47:54,:)) ; sum(epg(55:62,:))];

  index = ((8:-1:1) * P) ./ S;

elseif strcmp(index_name,'LAT')

  S = sum(epg);

  pal = reshape(pal,64,1);

  pal = pal(~isnan(pal));

  index = sum(epg(pal(1:30),:)) - sum(epg(pal(31:62),:));

  index = index ./ S;

elseif strcmp(index_name,'Row 8')

  index = sum(epg(55:62,:));   

elseif strcmp(index_name,'Rows 1-2')

  index = sum(epg(1:14,:));

end
