function epgprn

% EPGPRN: EPG printout.
%
%	EPGPRN prints the EPG patterns between cursor 1
%	and cursor 2.
%
%	See also: EPGFIG, PLOTEPG

%	N. Nguyen, 21/02/96

global epg epg_sr epg_pal

if ~exist('epg')
  fprintf(1,'\nEPG data not available.\n');
  return;
end

t1 = crsrloc(1);
t2 = crsrloc(2);

if t2 < t1
  dummy = t1;
  t1 = t2;
  t2 = dummy;
end

pat = floor(t1 * epg_sr)+1:floor(t2 * epg_sr)+1;

npat = length(pat);

h_mrkr = findobj('Tag','MarkerLine');

if ~isempty(h_mrkr);

  h_axes = get(h_mrkr(1),'Parent');

  h_mrkr =  findobj(h_axes,'Tag','MarkerLine');

  j = 1;

  for i = 1:length(h_mrkr)

    t = get(h_mrkr(i),'XData');
    t = t(1);

    if t >= t1 & t <= t2
      marked_pat(j) = floor(t * epg_sr) - pat(1) + 2;
      j = j + 1;
    end

  end

  marked_pat = sort(marked_pat);

end

h_fig = findobj('Name','EPG');

if isempty(h_fig)
  error('cannot access EPG window.');
  return;
end

patterns = epg(pat,:);

nrows = 8;
ncols = 12;

nplots = nrows*ncols;

x = epg_pal(:,1);
y = -epg_pal(:,2);

i = 1;

figure;
set(gcf,'UserData','EMA Tools');

for j = 1:npat

  h_axes(j) = subplot(nrows,ncols,i);

  set(h_axes(j),'Box','on','NextPlot','add','XTick',[],'YTick',[]);

  e_on = find(patterns(j,:)' == 1);
  e_off = find(patterns(j,:)' == 0);

 % h_line1 = plot(x(e_on),y(e_on),'g.');
  h_line1 = plot(x(e_on),y(e_on),'go');
 %set(h_line1,'MarkerSize',12);
  set(h_line1,'MarkerSize',2);
  h_line2 = plot(x(e_off),y(e_off),'.');
  set(h_line2,'MarkerSize',2);

  axis equal;
  axis off;

  title([' ' num2str(pat(j))],'FontName','Courier','FontSize',8);

  i = i + 1;

  if i > nplots
    figure;
    set(gcf,'UserData','EMA Tools');
    i = 1;
  end

end

if exist('marked_pat')

  for i = 1:length(marked_pat)

    h_fig = get(h_axes(marked_pat(i)),'Parent');

    figure(h_fig);

    subplot(h_axes(marked_pat(i)));

    axis on;

  end

end
