function extremum

% EXTREMUM: find local extremum on any kinematic curve
%
%      EXTREMUM finds the next local extremum to the right of
%      the left cursor on any activated track.

%      N. Nguyen, Feb. 96

%global h_axes h_lines
   h_fig = findobj(0,'Tag','EmaTools-Waveform');
	%find every axis belonging to any figure with an Ematools tag  
	h_axes = findobj(h_fig,'Type','axes');
	%find any lines belonging to these axes with a waveform tag (ie. not a cursor tag)
	h_lines = findobj(h_axes,'Tag','WaveForm','Selected','On');
   h_time1 = findobj(h_fig,'Tag','CursorTime','UserData',1);

   h_time2 = findobj(h_fig,'Tag','CursorTime','UserData',2);

ntrack = fndtrack('ACTIVE');

if isempty(ntrack)
  return;
end

t = get(h_lines(ntrack),'XData');
y = get(h_lines(ntrack),'YData');

crsr1 = crsrloc(1);
crsr2 = crsrloc(2);

pt = get(gca,'CurrentPoint');

if abs(pt(1,1) - crsr1) < abs(pt(1,1) - crsr2)
  t1 = crsr1;
  crsr = 1;
  h_time = h_time1;
else
  t1 = crsr2;
  crsr = 2;
  h_time = h_time2;
end

samp = find(t >= t1);

slope = sign(y(samp(1)) - y(samp(2)));
 
for i = 2:(length(samp)-1)

  if sign(y(samp(i)) - y(samp(i+1))) == -slope

    break;

  end

end
string = sprintf('Time(s)\n%7.3f',t(samp(i)));
set(h_time,'String',string);

crsrmove(crsr,t(samp(i)) - t1);
plotfft('FFT1',t(samp(i)) - t1);
plotepg('EPG1',t(samp(i)) - t1);
plotema('EMA1',t(samp(i)) - t1);

