function loadepg(filename)

% LOADEPG: load EPG signal
%
%        See also: LOADAUD, LOADEMA.

%        N. Nguyen, June 96, April 97

global EPGFILEEXT
global epg

h_fig = fndwin('EMA Tools');

if isempty(h_fig)
  fprintf(1,'\nEMA Tools is not running\n');
end

if nargin == 0

  [filename,pathname] = uigetfile(['*.' EPGFILEEXT],...
                                   'Load EPG Signal');

  if isempty(filename)
    return;
  else
    filename = [pathname filename];
  end

end

dots = findstr(filename,'.');
if ~isempty(dots)
  EPGFILEEXT = filename(1,dots(length(dots))+1:length(filename));
else
  fprintf(1,'%s is not a valid file name.\n',filename);
  return;
end

switch EPGFILEEXT

  case 'epg'

    eval(['load ' filename ' -mat;']);

  case 'ep2'

    fid = fopen(filename,'r');
    dummy = fread(fid,'short');
    nbits = 16 * length(dummy);
    frewind(fid);
    [epg,count] = fread(fid,nbits,'ubit1');
    if count ~= nbits
      fprintf(1,'Warning: %d bits read for %s.epg.raw\n',count,filename);
    end
    nbits = count;
    nframes = nbits / 96;
    epg = reshape(epg,96,nframes);
    epg = fliplr(epg');
    epg = epg(:,33:96);
    epg(:,[1 8]) = [];

  case 'ep3'

    fid = fopen(filename,'r');
    dummy = fread(fid,'short');
    nbits = 16 * length(dummy);
    fprintf(1,'nb. of bits: %d\n',nbits);
    frewind(fid);
    [epg,count] = fread(fid,nbits,'ubit1');
    if count ~= nbits
      fprintf(1,'Warning: %d bits read for %s.epg.raw\n',count,filename);
    end
    nbits = count;
    nframes = nbits / 64;
    epg = reshape(epg,64,nframes);
    epg = fliplr(epg');
    epg(:,[1 8]) = [];

  otherwise

    fprintf(1,'Unknown file extension.\n');
    return;

end
