function loadaud(filename)

% LOADLAR: load laryngograph signal
%
%        See also: LOADEMA, LOADEPG.

%        N. Nguyen, June 96, April 97

global LARFILEEXT
global FILEROOTNAME
global ema epg
global lar_sr tlim h_axes

h_fig = fndwin('EMA Tools');

if isempty(h_fig)
  fprintf(1,'\nEMA Tools is not running\n');
end

if nargin == 0

  [filename,pathname] = uigetfile(['*.' LARFILEEXT],...
                                   'Load Audio Signal');
 
  if isempty(filename)
    return;
  else
    filename = [pathname filename];
  end

end
% get filestem and add new postfixes
dots = findstr(filename,'.');

if ~isempty(dots)
  FILEROOTNAME = filename(1,1:dots(length(dots))-1);
  LARFILEEXT = filename(1,dots(length(dots))+1:length(filename));
else
  fprintf(1,'%s is not a valid file name.\n',filename);
  return;
end

switch LARFILEEXT

  case 'aud'

    eval(['load ' filename ' -mat;']);

  case 'lar'

    fid = fopen(filename,'r');
    y = fread(fid,'short');

  otherwise

    fprintf(1,'Unknown file extension.\n');
    return;

end

t = tscale(y,lar_sr);

dispsig(y,t,'amplitude',2,'LAR');

tlim = [0 t(length(t))];

set(h_axes,'XLim',tlim);

set(h_fig,'Name',['EMA Tools: ' FILEROOTNAME]);

for i = 3:length(h_axes)
  clrtrack(i);
end

if exist('ema')
  clear global ema;
end

if exist('epg')
  clear global epg;
end

delete(get(findobj('Label','EMA'),'Children'));

