% SPECPLOT: load AUDIO, Laryngograph, EMA and EPG  signals
%
%        A. Wrench, Feb 99

global ema epg
global aud_sr tlim %h_axes 
global ema_sr
global NTRACKS
global FILEROOTNAME
%global h_lines h_specgram
global ref1 ref2 plot_coils tongue_coils

%h_fig = fndwin('EMA Tools');
h_fig = findobj(0,'Tag','EmaTools-Waveform')
for i = 1:length(h_fig)
 if ~isempty(findobj(h_fig(i),'Tag','SGM'))
	close(h_fig(i));
 end
end

h_fig = findobj(0,'Tag','EmaTools-Waveform')

specwindow = 2;

if isempty(h_fig)
  fprintf(1,'\nEMA Tools is not running\n');
end

if NTRACKS ~= 9 
  NTRACKS = 9; 
end

mktracks(NTRACKS,'EmaTools-Waveform'); 

%find every axis belonging to any figure with an Ematools tag  
h_axes = findobj(h_fig,'Type','axes');
%find any lines belonging to these axes with a waveform tag (ie. not a cursor tag)
h_lines = findobj(h_axes,'Tag','WaveForm');

trackNum = 1;

name = input ('filename prefix (eg. hs151001,hs151002,im141002): ','s');
if strcmp(name, '')
	name = '';
end

tlim = [0 0];

FILEROOTNAME = [name];

fprintf('Loading...\n');

%----------------------------------------
% LOADING AUDIO TRACK

filename = [name '.wav'];

if exist(filename,'file')
   %raw unscaled output
   mode = 'r';
   %unlimited samples
   nmax = -1;
% skip no samples at start of file
   nskip = 0;
   [audio, aud_sr, ffmt] = readaud(filename,mode,nmax,nskip);
   t = tscale(audio,aud_sr);
   
   if (t(length(t)) > tlim(2))
      tlim = [0 t(length(t))];
      set(h_axes(trackNum),'XLim',tlim);
      set(h_fig,'Name',['EMA Tools: ' name ]);
   end

%audio = audio + rand(size(audio))*2000;

nchans = ffmt{5};
chan_num = 1;
if nchans > 1
  fprintf('This audio file has %d channels.\n',nchans);
  chan_str  = input ('Select an channel number to display (default:1):','s');

  if strcmp(chan_str,'')
    chan_str = '1';
  end
  chan_num = str2num(chan_str);
end

%h_specgram = findobj('Tag','Spectrogram');
%if ishandle(h_specgram)

%   dispspec(audio(:,chan_num),t,'',1,'SGM');
%end
if trackNum > NTRACKS 
   return
end
% Display waveform of acoustic signal(s) 
   dispsig(audio(:,chan_num),t,'',trackNum,'AUD');
   
   trackNum = trackNum+1;


else 
   fprintf('Filename: %s not present\n',filename);
end

   pack;

%----------------------------------------
% LOADING LARYNGOGRAPH TRACK

filename = [name '.lar'];

if exist(filename,'file')

%raw unscaled output
   mode = 'r';
%unlimited samples
   nmax = -1;
% skip no samples at start of file
   nskip = 0;
   [laryngo, aud_sr, ffmt] = readaud(filename,mode,nmax,nskip);

t = tscale(laryngo,aud_sr);

   if (t(length(t)) > tlim(2))
      tlim = [0 t(length(t))];
      set(h_axes(trackNum),'XLim',tlim);
      set(h_fig,'Name',['EMA Tools: ' name ]);
   end
   
if trackNum > NTRACKS 
   return
end

% Display laryngograph signal on next track 
   dispsig(laryngo,t,'lar',trackNum,'LAR');
   trackNum = trackNum+1;
else 
   fprintf('Filename: %s not present\n',filename);
end

   pack;
%---------------------------------------------
% LOADING FORMANT TRACKS

filename = [name '.fmt'];

if exist(filename,'file')

%raw unscaled output
   mode = 'r';
%unlimited samples
   nmax = -1;
% skip no samples at start of file
   nskip = 0;
   [fmt, fmt_sr, ffmt, t] = readest(filename,mode,nmax,nskip);

%   t = tscale(tmp_ema,ema_sr);

   if (t(length(t)) > tlim(2))
      tlim = [0 t(length(t))];
      set(h_axes(trackNum),'XLim',tlim);
      set(h_fig,'Name',['EMA Tools: ' name ]);
   end

   chan =ffmt{5};

%display  selected channels on sequential tracks
   fmt_index=0;
   for i=1:size(chan,1)
      if (findstr('F3', chan(i,:)))
        fmt_index=i;
        break;
      end
   end
   if trackNum > NTRACKS 
   	return
	end

   if fmt_index
      dispsig(fmt(:,fmt_index),t,chan(fmt_index,:),trackNum,'TIM');
      trackNum = trackNum+1;
   end

   fmt_index=0;
   for i=1:size(chan,1)
      if (findstr('F2', chan(i,:)))
        fmt_index=i;
        break;
      end
   end
   if trackNum > NTRACKS 
   	return
	end
   if fmt_index
      dispsig(fmt(:,fmt_index),t,chan(fmt_index,:),trackNum,'TIM');
      trackNum = trackNum+1;
   end

   fmt_index=0;
   for i=1:size(chan,1)
      if (findstr('F1', chan(i,:)))
        fmt_index=i;
        break;
      end
   end
   if trackNum > NTRACKS 
   	return
	end
   if fmt_index
      dispsig(fmt(:,fmt_index),t,chan(fmt_index,:),trackNum,'TIM');
      trackNum = trackNum+1;
   end
%findobj('UserData','SGM')
%if ~isempty(findobj('UserData','SGM'))
%dispfmt(fmt(:,1),t,chan(fmt_index,:),1,'F1');
%end


%figure;
%shift = 32;
%pad = zeros(100,1);
%yy = [pad; audio(:,chan_num)];
%yyy = 50*yy;
%[b,f,tt] = specgram(yyy,512,aud_sr,200,200-shift);
%clims = [70 140];
%h_specgram = imagesc(tt,f,20*log10(abs(b)),clims);axis xy;colormap(flipud(bone));
%hold;
%plot(t,fmt(:,1:5));


else
   fprintf('Filename: %s not present\n',filename);
end

pack;

%----------------------------------------
% LOADING PITCH TRACK

filename = [name '.f0'];

if exist(filename,'file')

%raw unscaled output
   mode = 'r';
%unlimited samples
   nmax = -1;
% skip no samples at start of file
   nskip = 0;
   [tmp_pitch, pitch_sr, ffmt,t] = readest(filename,mode,nmax,nskip);
% increment through laryngograph samples and set pitch to last recorded pitch value
  tlar = tscale(laryngo,aud_sr);
  if name(1) == 'f'
    lowest_pitch = 0.0125;
  else
    lowest_pitch = 0.02;
  end
  pitch=ones(size(laryngo));
  j = 1;
  tpitchlim = length(t);
  tlarlim = length(tlar);
  lastvalidpitch = 0;
  for i=1:tlarlim
    if tlar(i) < t(j)
	pitch(i)= lastvalidpitch;
    else 
	if j<tpitchlim
	  lastvalidpitch=tmp_pitch(j);
	  j=j+1;
	  if t(j) - t(j-1) >lowest_pitch
		lastvalidpitch = 0;
	  end
	else
	  lastvalidpitch=0;
          t(j) = tlar(tlarlim);
	end;
	pitch(i)= lastvalidpitch;
    end
  end
    pitch_sr = aud_sr;

  t = tlar;
  clear tlar;
  clear tmp_pitch;
%   t = tscale(pitch,pitch_sr);

   if (t(length(t)) > tlim(2))
      tlim = [0 t(length(t))];
      set(h_axes(trackNum),'XLim',tlim);
      set(h_fig,'Name',['EMA Tools: ' name ]);
   end
   if trackNum > NTRACKS 
   	return
	end

% Display pitch signal on next track
   dispsig(pitch,t,'f0',trackNum,'F0');
   trackNum = trackNum+1;
else
   fprintf('Filename: %s not present\n',filename);
end

   pack;

%---------------------------------------------
% LOADING EMA TRACKS

filename = [name '.ema'];

if exist(filename,'file')
   
%raw unscaled output
   mode = 'r';
%unlimited samples
   nmax = -1;
% skip no samples at start of file
   nskip = 0;
   [tmp_ema, ema_sr, ffmt, t] = readest(filename,mode,nmax,nskip);
   
%   t = tscale(tmp_ema,ema_sr);

   if (t(length(t)) > tlim(2))
      tlim = [0 t(length(t))];
      set(h_axes(trackNum),'XLim',tlim);
      set(h_fig,'Name',['EMA Tools: ' name ]);
   end

   tmp_chan =ffmt{5};

% sort xxxxxyyyyyxxxxxyyyyy to xxxxxxxxxxyyyyyyyyyy
%ema = [];ema_chan = [];
%[nchans,labelSize] = size(tmp_chan);
%j=1;
%for i= 1:5
%	ema(:,j)= tmp_ema(:,i);
%	ema_chan(j,:) = tmp_chan(i,:);
%	j=j+1;
%end
%for i= 11:15
%        ema(:,j)= tmp_ema(:,i);
%        ema_chan(j,:) = tmp_chan(i,:);
%	j=j+1;
%end
%for i= 6:10
%        ema(:,j)= tmp_ema(:,i);
%        ema_chan(j,:) = tmp_chan(i,:);
%	j=j+1;
%end
%for i= 16:20
%        ema(:,j)= tmp_ema(:,i);
%        ema_chan(j,:) = tmp_chan(i,:);
%	j=j+1;
%end

%tmp_chan=char(ema_chan);
ema_chan= tmp_chan;
clear tmp_chan;

ema_scaling = 0.01;
%tmp_ema = ema_scaling*ema;
ema = ema_scaling*tmp_ema;
%ema = tmp_ema;
clear tmp_ema;


%-------------------------------
%Load EMA tracks into EMA menu
   M = findobj('Label','EMA');
   delete(findobj(M,'Tag','Channels'));

   for j = 1:size(ema_chan,1)
     callbackstring = [...
       'label = get(gcbo,''Label'');'...
       'y = get(gcbo,''UserData'');'...
       'global ema_sr; t = tscale(y,ema_sr);'...
       'dispsig(y,t,label);'];
 
       uimenu(M,'Label',ema_chan(j,:),'Callback',callbackstring,...
                'Tag','Channels','UserData',ema(:,j));
  
   end
%-----------------------------------------

%Set coils to be plotted for 2D plot and the refernce coils
   plot_coils=[];
   for i=1:size(ema_chan,1)
      switch ema_chan(i,:)
	case 'ui_x'
		ref1=i;
		plot_coils = [plot_coils i];
	case 'bn_x'
		ref2=i;
	case 'ul_x'
		plot_coils = [plot_coils i];
	case 'll_x'
		plot_coils = [plot_coils i];
	case 'tt_x'
		plot_coils = [plot_coils i];
	case 'tb_x'
		plot_coils = [plot_coils i];
	case 'td_x'
		plot_coils = [plot_coils i];
	case 'li_x'
		plot_coils = [plot_coils i];
	case 'v_x'
		plot_coils = [plot_coils i];
      end
   end

%Set linked tongue coils (in sequence) for 2D plot
   tongue_coils=[];
   for i=1:size(ema_chan,1)
      if (findstr('tt_x', ema_chan(i,:))) 
	tongue_coils=[tongue_coils i];
	break;
      end
   end
   for i=1:size(ema_chan,1)
      if (findstr('tb_x', ema_chan(i,:))) 
	tongue_coils=[tongue_coils i];
	break;
      end
   end
   for i=1:size(ema_chan,1)
      if (findstr('td_x', ema_chan(i,:))) 
	tongue_coils=[tongue_coils i];
	break;
      end
   end

%display  selected channels on sequential tracks
   ema_index=0;
   for i=1:size(ema_chan,1)
      if (findstr('ul_y', ema_chan(i,:))) 
	ema_index=i;
	break;
      end
   end
   if trackNum > NTRACKS 
   	return
	end
   if ema_index
      dispsig(ema(:,ema_index),t,ema_chan(ema_index,:),trackNum,'TIM');
      trackNum = min([trackNum+1 NTRACKS]);
   end

   ema_index=0;
   for i=1:size(ema_chan,1)
      if (findstr('ll_y', ema_chan(i,:))) 
	ema_index=i;
	break;
      end
   end
   if trackNum > NTRACKS 
   	return
	end
   if ema_index
      dispsig(ema(:,ema_index),t,ema_chan(ema_index,:),trackNum,'TIM');
      trackNum = min([trackNum+1 NTRACKS]);
   end

   ema_index=0;
   for i=1:size(ema_chan,1)
      if (findstr('tt_y', ema_chan(i,:))) 
	ema_index=i;
	break;
      end
   end
   if trackNum > NTRACKS 
   	return
	end
   if ema_index
      dispsig(ema(:,ema_index),t,ema_chan(ema_index,:),trackNum,'TIM');
      trackNum = min([trackNum+1 NTRACKS]);
   end

   ema_index=0;
   for i=1:size(ema_chan,1)
      if (findstr('tb_y', ema_chan(i,:))) 
	ema_index=i;
	break;
      end
   end
   if trackNum > NTRACKS 
   	return
	end
   if ema_index
      dispsig(ema(:,ema_index),t,ema_chan(ema_index,:),trackNum,'TIM');
      trackNum = min([trackNum+1 NTRACKS]);
   end

   ema_index=0;
   for i=1:size(ema_chan,1)
      if (findstr('td_y', ema_chan(i,:))) 
	ema_index=i;
	break;
      end
   end
   if trackNum > NTRACKS 
   	return
	end
   if ema_index
      dispsig(ema(:,ema_index),t,ema_chan(ema_index,:),trackNum,'TIM');
      trackNum = min([trackNum+1 NTRACKS]);
   end

   ema_index=0;
   for i=1:size(ema_chan,1)
      if (findstr('li_y', ema_chan(i,:))) 
	ema_index=i;
	break;
      end
   end
   if trackNum > NTRACKS 
   	return
	end
   if ema_index
      dispsig(ema(:,ema_index),t,ema_chan(ema_index,:),trackNum,'TIM');
      trackNum = min([trackNum+1 NTRACKS]);
   end

   ema_index=0;
   for i=1:size(ema_chan,1)
      if (findstr('v_y', ema_chan(i,:)))
        ema_index=i;
        break;
      end
   end
   if trackNum > NTRACKS 
   	return
	end
   if ema_index
      dispsig(ema(:,ema_index),t,ema_chan(ema_index,:),trackNum,'TIM');
      trackNum = min([trackNum+1 NTRACKS]);
   end


%display channel  17 on track 8
%dispsig(ema(:,17),t,ema_chan(17,:),trackNum,'TIM');
%trackNum = trackNum+1;
 
%display distance from jaw to velum on channel 9
%  y1 = ema(:,2);
%  t1 = t;
%  y2 = ema(:,12);
%  y3 = ema(:,8);
%  y4 = ema(:,18);
%  [yy,t2] = absdist(y1,y2,y3,y4,t1);
%  dispsig(yy,t2,'scal. dist.',trackNum);
%  trackNum = trackNum+1;

%display distance from jaw to fixed point on channel 4
%  y1 = ema(:,10);
%  t1 = t;
%  y2 = ema(:,20);
%  y3 = ones(length(y1),1) * 70;
%  y4 = ones(length(y2),1) * 120;
%  [jaw,t2] = absdist(y1,y2,y3,y4,t1);
%  dispsig(jaw,t2,'jaw',trackNum);
%  trackNum = trackNum+1;
%  set(h_axes(5),'YTickLabelMode','auto');

%display distance from velum to fixed point on channel 3
%  y1 = ema(:,8);
%  t1 = t;
%  y2 = ema(:,18);
%  y3 = ones(length(y1),1) * 130;
%  y4 = ones(length(y2),1) * 190;
%  [yyy,t2] = absdist(y1,y2,y3,y4,t1);
%  dispsig(-yyy,t2,'velum',trackNum);
%  trackNum = trackNum+1;
%  set(h_axes(4),'YTickLabelMode','auto');

%display distance between lips on channel 5
%  y1 = ema(:,3);
%  t1 = t;
%  y2 = ema(:,13);
%  y3 = ema(:,4);
%  y4 = ema(:,14);
%  [lips,t2] = absdist(y1,y2,y3,y4,t1);
%  dispsig(-lips,t2,'lips',trackNum);
%  trackNum = trackNum+1;
%  set(h_axes(6),'YTickLabelMode','auto');

%display distance from tongue dorsum to fixed point on channel 6
%  y1 = ema(:,5);
%  t1 = t;
%  y2 = ema(:,15);
%  y3 = ones(length(y1),1) * 90;
%  y4 = ones(length(y2),1) * 140;
%  [ttip,t2] = absdist(y1,y2,y3,y4,t1);
%  dispsig(ttip,t2,'tip/blade',trackNum);
%  trackNum = trackNum+1;
%  set(h_axes(7),'YTickLabelMode','auto');

%display distance from tongue dorsum to fixed point on channel 8
%  y1 = ema(:,7);
%  t1 = t;
%  y2 = ema(:,17);
%  y3 = ones(length(y1),1) * 150;
%  y4 = ones(length(y2),1) * 190;
%  [tdstyl,t2] = absdist(y1,y2,y3,y4,t1);
%  dispsig(-tdstyl,t2,'dorsum-SG',trackNum);
%  trackNum = trackNum+1;
%  set(h_axes(9),'YTickLabelMode','auto');
%  [stylvel,t2] = deriv(-tdstyl,t1,'vel');
%  [stylvelsm,t3] = smooth(stylvel,t2,11);
%  [stylacc,t4] = deriv(stylvelsm,t3,'vel');


%display distance from tongue dorsum to fixed point on channel 7
%  y1 = ema(:,7);
%  t1 = t;
%  y2 = ema(:,17);
%  y3 = ones(length(y1),1) * 100;
%  y4 = ones(length(y2),1) * 200;
%  [tdpal,t2] = absdist(y1,y2,y3,y4,t1);
%  dispsig(-tdpal,t2,'dorsum-PG',trackNum);
%  trackNum = trackNum+1;
%  set(h_axes(8),'YTickLabelMode','auto');
%  [palvel,t2] = deriv(-tdpal,t1,'vel');

%display difference between tracks 10 and 9 on channel 8
%dif = yyy - yy;
%dispsig(dif,t,'vel-jaw dif',trackNum,'TIM');
%dif = yyyy + tdepth;
%dispsig(dif,t,'td-depth',trackNum,'TIM');
%  trackNum = trackNum+1;
 

%display difference between td-palatoglosus and jaw on channel 8
%dif = tdpal - jaw;
%dispsig(-dif,t,'tdpal-jaw',trackNum,'TIM');
%  trackNum = trackNum+1;
 
   
else 
   fprintf('Filename: %s not present\n',filename);
end

pack;
%------------------------------------------
%Load EPG data

filename = [name '.epg'];

if exist(filename,'file')
    fid = fopen(filename,'r');
    dummy = fread(fid,'short');
    nbits = 16 * length(dummy);
    frewind(fid);
    [epg,count] = fread(fid,nbits,'ubit1');
    if count ~= nbits
      fprintf(1,'Warning: %d bits read for %s.epg.raw\n',count,filename);
    end
    nbits = count;
%    nframes = nbits / 96;
%    epg = reshape(epg,96,nframes);
%    epg = fliplr(epg');
%    epg = epg(:,33:96);
%    epg(:,[1 8]) = [];
    nframes = nbits / 64;
    epg = reshape(epg,64,nframes);
    epg = fliplr(epg');
    epg(:,[1 8]) = [];
else 
   fprintf('Filename: %s not present\n',filename);
end
  epg_sr = 100;
  y = epgindex(epg,'TOT');
  t = tscale(y,epg_sr);
   if (t(length(t)) > tlim(2))
      tlim = [0 t(length(t))];
      set(h_axes(trackNum),'XLim',tlim);
   end

  dispsig(y,t,label,trackNum,'EPG');
  trackNum = trackNum+1;

  y = epgindex(epg,'ANT');
  t = tscale(y,epg_sr);
  dispsig(y,t,'ANT',trackNum,'EPG');
  trackNum = trackNum+1;
  y = epgindex(epg,'PST');
  t = tscale(y,epg_sr);
  dispsig(y,t,'PST',trackNum,'EPG');
  trackNum = trackNum+1;
  y = epgindex(epg,'ALV');
  t = tscale(y,epg_sr);
  dispsig(y,t,'ALV',trackNum,'EPG');
  trackNum = trackNum+1;
  y = epgindex(epg,'PAL');
  t = tscale(y,epg_sr);
  dispsig(y,t,'PAL',trackNum,'EPG');
  trackNum = trackNum+1;
  y = epgindex(epg,'VEL');
  t = tscale(y,epg_sr);
  dispsig(y,t,'VEL',trackNum,'EPG');
  trackNum = trackNum+1;
  y = epgindex(epg,'COG');
  t = tscale(y,epg_sr);
  dispsig(y,t,'COG',trackNum,'EPG');
  trackNum = trackNum+1;
  y = epgindex(epg,'LAT');
  t = tscale(y,epg_sr);
  dispsig(y,t,'LAT',trackNum,'EPG');
  trackNum = trackNum+1;

%------------------------------------------
%Start Spectrogram
findobj(findobj(0,'Tag','Ematools-Waveform'),'Tag','SGM')
if isempty(findobj(findobj(0,'Tag','Ematools-Waveform'),'Tag','SGM'))
   newactivate(h_axes(1));
   specfig;
end

%------------------------------------------
%Load Label data

filename = [name '.lab'];

if exist(filename,'file')
   mrkrload(filename);
else 
   fprintf('Filename: %s not present\n',filename);
end
