function phi = phaseprt

% PHASEPRT: compute position of Marker 1 relative to that
%        of left cursor in the phase plane for the activated
%        kinematic parameter

%        N. Nguyen, June 96

global h_axes h_lines

ntrack = fndtrack('ACTIVE');

if isempty(ntrack)
  return;
end

y = get(h_lines(ntrack),'YData');

nsamp = length(y);

period = get(get(h_axes(ntrack),'xlabel'),'UserData');

samp1 = floor(crsrloc(1) / period) + 1;
samp2 = floor(crsrloc(2) / period) + 1;

if samp1 > samp2
  dummy = samp1;
  samp1 = samp2;
  samp2 = dummy;
end

samp1 = max([2 samp1]);
samp2 = min([(nsamp-1) samp2]);

h_mrkr = findobj(h_axes(ntrack),'Tag','MarkerLine');

if ~isempty(h_mrkr);

  for i = 1:length(h_mrkr)

    t = get(h_mrkr(i),'XData');
    t = t(1);
    marked_samp(i) = floor(t / period) + 1;

  end

  marked_samp = sort(marked_samp);

end

yy = (y(3:nsamp) - y(1:(nsamp-2))) / (period*2);

y = y(samp1:samp2);
yy = yy(samp1-1:samp2-1);

marked_samp = marked_samp - samp1 + 1;

y = (2 * y) ./ (max(y) - min(y));

y = y - (((max(y) + min(y)) / (max(y) - min(y))) * ones(size(y)));

if yy(marked_samp(1)) > 0
  yy = yy ./ max(yy(yy > 0));
else
  yy = yy ./ (-min(yy(yy < 0)));

end

y = y(:);
yy = yy(:);

Y = [yy y];

phi = angle(Y(:,1) + sqrt(-1)*Y(:,2))/pi * 180;

phi = phi - phi(1);

i = find(phi < 0);

phi(i) = 360 + phi(i);

delta_phi = phi(2:length(phi)) - phi(1:length(phi)-1);

delta_phi = min([abs(delta_phi) (360 - abs(delta_phi))]')';

phi = [0 ; cumsum(delta_phi)];

h_fig = findobj('Type','figure','Name','Phase portrait');

if isempty(h_fig)
  h_fig = figure;
  set(h_fig,'Name','Phase portrait','NumberTitle','off',...
            'UserData','EMA Tools');
end

figure(h_fig);

clf

plot(Y(:,1),Y(:,2));

hold on;

plot([0 Y(1,1)],[0 Y(1,2)],'--');

h_text = text(Y(1,1),Y(1,2),'0');

set(h_text,'FontName','Courier','FontSize',8,...
    'VerticalAlignment','middle','HorizontalAlignment','center');

if exist('marked_samp')

  for i = 1:length(marked_samp)

    yy = Y(marked_samp(i),1);
    y = Y(marked_samp(i),2);

    plot([0 yy],[0 y],'--');

    h_text = text(yy,y,num2str(i));

    set(h_text,'FontName','Courier','FontSize',8,...
        'VerticalAlignment','middle','HorizontalAlignment','center');

    fprintf(1,'marker %d - phi = %f\n',i,phi(marked_samp(i)));

  end

  phi = phi(marked_samp);

else

  phi = [];

end

plot([-1.1 1.1],[0 0],':');
plot([0 0],[-1.1 1.1],':');

set(gca,'XLim',[-1.1 1.1],'YLim',[-1.1 1.1],'XTick',-1:.2:1,...
    'YTick',-1:.2:1);

xlabel('velocity');
ylabel('displacement');

