function plotema3

% PLOTEMA3: plot x and y coordinates of the tongue coils at the red
%       cursor location, with a 3D display of the subject's palate
%

% See also: EMAFIG, PLOTEMA.

%	N. Nguyen, July 96

global ema_sr ema epg_pal

if ~exist('ema')
  fprintf(1,'\nEMA data not available.\n');
  return;
end

t = crsrloc(1);

t = floor(t * ema_sr) + 1;

if t > size(ema,1)
  return;
end

ncoord = size(ema,2);
ncoils = ncoord / 2;

x = ema(t,1:ncoils);
y = ema(t,ncoils+1:ncoord);

m = [-2*ones(1,ncoils-1);...
      2*ones(1,ncoils-1);...
      2*ones(1,ncoils-1);
     -2*ones(1,ncoils-1)];

h_fig = findobj('Name','EMA 3D');

if isempty(h_fig)

  figure;

  set(gcf,'Name','EMA 3D','NumberTitle','off','UserData','EMA Tools');
  
  pal = epg_pal;

  pal = [NaN NaN NaN; pal(1:6,:) ; NaN NaN NaN ; pal(7:62,:)];

  elctr = [...
     1     2     3     4     5     6     7     8
     9    10    11    12    13    14    15    16
    17    18    19    20    21    22    23    24
    25    26    27    28    29    30    31    32
    33    34    35    36    37    38    39    40
    41    42    43    44    45    46    47    48
    49    50    51    52    53    54    55    56
    57    58    59    60    61    62    63    64];

  for i = 1:8

    row = pal(elctr(i,:),:);

    plot3(row(:,1),row(:,2),row(:,3));
    hold on

  end

  for j = 1:8

    col = pal(elctr(:,j),:);

    plot3(col(:,1),col(:,2),col(:,3));

  end

  axis equal

  az = 60;
  el = 20;
  view(az,el);

  callbackstring = [...
    '[az,el] = view;'...
    'view(get(get(gcf,''CurrentObject''),''Value''),el);'];

  h = uicontrol('Style','Slider','Units','Normal',...
                'Position',[.01 .01 .3 .03],'Max',360,'Min',0,...
                'Value',az,'Callback',callbackstring);

  callbackstring = [...
    '[az,el] = view;'...
    'view(az,get(get(gcf,''CurrentObject''),''Value''));'];

  h = uicontrol('Style','Slider','Units','Normal',...
                'Position',[.01 .045 .03 .3],'Max',360,'Min',0,...
                'Value',el,'Callback',callbackstring);

  h = fill3(m,[x(1:ncoils-1);x(1:ncoils-1);x(2:ncoils);x(2:ncoils)],...
              [y(1:ncoils-1);y(1:ncoils-1);y(2:ncoils);y(2:ncoils)],'r');

else

  figure(h_fig);

  delete(findobj(h_fig,'Type','patch'));

  h = fill3(m,[x(1:ncoils-1);x(1:ncoils-1);x(2:ncoils);x(2:ncoils)],...
              [y(1:ncoils-1);y(1:ncoils-1);y(2:ncoils);y(2:ncoils)],'r');

end
