function plotfft(spec,t)

% PLOTFFT: display an FFT of the audio signal computed at the current
%	cursor's location.
%
%	See also: FFTFIG, RMSINT, ZERCROSS.

%	N. Nguyen, July 95, 18/09/95

global aud_sr 
%find every axis belonging to any figure with an Ematools tag  
h_axes = findobj(findobj(0,'Tag','EmaTools-Waveform'),'Type','axes');
%find any lines belonging to these axes with a waveform tag (ie. not a cursor tag)
h_lines = findobj(h_axes,'Tag','WaveForm');

h_spec = findobj('UserData',spec);

if isempty(h_spec) | ~exist('aud_sr')
  return;
end

h_audio = h_lines(1);

ncomp = length(get(h_spec,'XData'));

npoints = ncomp * 2;

sample = floor(t * aud_sr) + 1;

left_border = sample - npoints/2;
right_border = left_border + npoints;

A = get(h_audio,'YData');

A = A(:);

nsamp = length(A);

if left_border < 1 | right_border > nsamp
  return;
end

A = diff(A(left_border:right_border));
F = fft(hamming(npoints) .* A);
F = 20 * log10 (abs(F));

set (h_spec,'YData',F(1:ncomp));

