function [Z,t2] = zercross(A,t,step,win_width)

% ZERCROSS: compute the rate of zero-crossings for the audio signal.
%
%	step and win_width are expressed in terms of number of samples.
%
%	See also: RMSINT.

%	N. Nguyen, July 95, 18/09/95

aud_period = t(2) - t(1);

%-------------------------------------------------------------------------------
% compute the zero-crossing rate

nsamp = length(A);
Z_period = aud_period * (step - 1);
win_duration = (win_width - 1) * aud_period;

sample = win_width;

i = 1;

while sample <= nsamp

  frame = A (sample-(win_width-1):sample);

  Z(i) = length(find(diff(sign(frame)) ~= 0));

  Z(i) = Z(i) / win_duration;

  sample = sample + step;

  i = i + 1;

end

nsamp = length(Z);

t1 = ((win_width-1) * aud_period) / 2;
t2 = t1 + (nsamp - 1) * Z_period;

t2 = t1:Z_period:t2;

